@@ -1,13 +1,11 @@
 import os
-import platform
 import re
-import sys
 import xml.etree.ElementTree as ET
 from datetime import datetime, timedelta, timezone
 from pathlib import Path
 
 import pytest
-from hypothesis import assume, example, given
+from hypothesis import assume, example, given, settings
 from hypothesis import strategies as st
 from hypothesis.strategies import integers
 from lxml.etree import XMLSyntaxError
@@ -19,14 +17,12 @@ from pikepdf.models.metadata import (
     XMP_NS_PDF,
     XMP_NS_XMP,
     DateConverter,
-    PdfMetadata,
     decode_pdf_date,
-    encode_pdf_date,
 )
 
 try:
     from libxmp import XMPMeta, XMPError
-except Exception:
+except Exception:  # throws libxmp.ExempiLoadError pylint: disable=broad-except
     XMPMeta, XMPError = None, None
 
 needs_libxmp = pytest.mark.skipif(
@@ -62,12 +58,6 @@ def trivial(resources):
     return Pdf.open(resources / 'pal-1bit-trivial.pdf')
 
 
-@pytest.fixture
-def enron1(resources):
-    # Has nuls in docinfo, old PDF
-    return Pdf.open(resources / 'enron1_gs.pdf')
-
-
 @pytest.fixture
 def invalid_creationdate(resources):
     # Has nuls in docinfo, old PDF
@@ -342,8 +332,25 @@ def test_remove_attribute_metadata(sandwich):
     assert not re.search(r'rdf:Description xmlns:[^\s]+ rdf:about=""/', str(xmp))
 
 
-def test_docinfo_problems(enron1, invalid_creationdate):
-    meta = enron1.open_metadata()
+def test_docinfo_problems(sandwich, invalid_creationdate):
+    sandwich.Root.Metadata = Stream(
+        sandwich,
+        b"""
+        <?xpacket begin='\xc3\xaf\xc2\xbb\xc2\xbf' id='W5M0MpCehiHzreSzNTczkc9d'?>
+        <?adobe-xap-filters esc="CRLF"?>
+        <x:xmpmeta xmlns:x='adobe:ns:meta/' x:xmptk='XMP toolkit 2.9.1-13, framework 1.6'>
+        <rdf:RDF xmlns:rdf='http://www.w3.org/1999/02/22-rdf-syntax-ns#' xmlns:iX='http://ns.adobe.com/iX/1.0/'>
+        <rdf:Description rdf:about='uuid:873a76ba-4819-11f4-0000-5c5716666531' xmlns:pdf='http://ns.adobe.com/pdf/1.3/' pdf:Producer='GPL Ghostscript 9.26'/>
+        <rdf:Description rdf:about='uuid:873a76ba-4819-11f4-0000-5c5716666531' xmlns:xmp='http://ns.adobe.com/xap/1.0/'><xmp:ModifyDate>2019-01-04T00:44:42-08:00</xmp:ModifyDate>
+        <xmp:CreateDate>2019-01-04T00:44:42-08:00</xmp:CreateDate>
+        <xmp:CreatorTool>Acrobat 4.0 Scan Plug-in for Windows&#0;</xmp:CreatorTool></rdf:Description>
+        <rdf:Description rdf:about='uuid:873a76ba-4819-11f4-0000-5c5716666531' xmlns:xapMM='http://ns.adobe.com/xap/1.0/mm/' xapMM:DocumentID='uuid:873a76ba-4819-11f4-0000-5c5716666531'/>
+        <rdf:Description rdf:about='uuid:873a76ba-4819-11f4-0000-5c5716666531' xmlns:dc='http://purl.org/dc/elements/1.1/' dc:format='application/pdf'><dc:title><rdf:Alt><rdf:li xml:lang='x-default'>Untitled</rdf:li></rdf:Alt></dc:title></rdf:Description>
+        </rdf:RDF>
+        </x:xmpmeta>
+        """,
+    )
+    meta = sandwich.open_metadata()
     meta._load()  # File has invalid XML sequence &#0;
     with meta:
         with pytest.warns(UserWarning) as warned:
@@ -358,14 +365,14 @@ def test_docinfo_problems(enron1, invalid_creationdate):
         assert 'could not be updated' in warned[0].message.args[0]
 
 
-def test_wrong_xml(enron1):
-    enron1.Root.Metadata = Stream(
-        enron1,
+def test_wrong_xml(sandwich):
+    sandwich.Root.Metadata = Stream(
+        sandwich,
         b"""
         <test><xml>This is valid xml but not valid XMP</xml></test>
     """.strip(),
     )
-    meta = enron1.open_metadata(strict=True)
+    meta = sandwich.open_metadata(strict=True)
     with pytest.raises(ValueError, match='not XMP'):
         with meta:
             pass
@@ -428,6 +435,7 @@ def test_degenerate_xml_recoverable(trivial, xml):
         xmp['pdfaid:part'] = '5'
 
 
+@settings(deadline=None)
 @given(st.integers(min_value=1, max_value=1350))
 @example(548)
 @example(1154)
@@ -528,3 +536,36 @@ def test_random_docinfo(docinfo):
             assert 'could not be copied to XMP' in str(e) or '/Dummy' in str(e)
         else:
             ET.fromstring(str(m))  # ensure we can parse it
+
+
+def test_set_empty_string(graph):
+    with graph.open_metadata() as m:
+        m['dc:title'] = 'a'
+
+    generated_xmp = graph.Root.Metadata.read_bytes()
+    print(generated_xmp)
+    assert generated_xmp.count(b'<dc:title>') == 1
+
+
+@pytest.mark.parametrize('fix_metadata', [True, False])
+def test_dont_create_empty_xmp(trivial, outpdf, fix_metadata):
+    trivial.save(outpdf, fix_metadata_version=fix_metadata)
+
+    with pikepdf.open(outpdf) as p:
+        assert Name.Metadata not in p.Root
+
+
+@pytest.mark.parametrize('fix_metadata', [True, False])
+def test_dont_create_empty_docinfo(trivial, outpdf, fix_metadata):
+    del trivial.trailer.Info
+    trivial.save(outpdf, fix_metadata_version=fix_metadata)
+
+    with pikepdf.open(outpdf) as p:
+        assert Name.Info not in p.trailer
+
+
+def test_issue_100(trivial):
+    with trivial.open_metadata() as m, pytest.warns(
+        UserWarning, match="no XMP equivalent"
+    ):
+        m.load_from_docinfo({'/AAPL:Example': pikepdf.Array([42])})
